@@ -25,8 +25,8 @@
 #include <KConfig>
 #include <KCModuleProxy>
 
-MainUi::MainUi(QWidget *parent)
-  : KCMultiDialog(parent),
+MainUi::MainUi(QWidget *parent) :
+    KCMultiDialog(parent),
     m_apperModule(0)
 {
     setCaption(QString());
@@ -39,11 +39,14 @@ MainUi::MainUi(QWidget *parent)
     // Set Apply and Cancel buttons
     setButtons(KDialog::Apply /*| KDialog::Help*/ | KDialog::Default | KDialog::Reset);
 
-    KPageWidgetItem *page = addModule("kcm_apper.desktop");
+    KPageWidgetItem *page = addModule(QLatin1String("kcm_apper.desktop"),
+                                      QStringList() << QLatin1String("apper"));
     if (page) {
         KCModuleProxy *proxy = static_cast<KCModuleProxy*>(page->widget());
         if (proxy) {
             m_apperModule = proxy->realModule();
+            connect(m_apperModule, SIGNAL(caption(QString)),
+                    this, SLOT(setCaption(QString)));
         }
     } else {
         kWarning() << "Could not load kcm_apper.desktop!";
