@@ -27,7 +27,7 @@
 
 #include <Transaction>
 
-#include <AppStream/CategoryMatcher.h>
+#include <CategoryMatcher.h>
 
 class CategoryModel : public QStandardItemModel
 {
@@ -70,6 +70,4 @@ private:
     QModelIndex  m_rootIndex;
 };
 
-Q_DECLARE_METATYPE(PackageKit::Transaction::Group)
-
 #endif
