@@ -52,7 +52,7 @@
 #include <config.h>
 
 #ifdef HAVE_APPSTREAM
-#include <AppStream/AppStreamDb.h>
+#include <AppStream.h>
 #endif
 
 #include "GraphicsOpacityDropShadowEffect.h"
@@ -76,6 +76,7 @@ PackageDetails::PackageDetails(QWidget *parent)
    m_hasFileList(false)
 {
     ui->setupUi(this);
+    ui->hideTB->setIcon(KIcon("window-close"));
     connect(ui->hideTB, SIGNAL(clicked()), this, SLOT(hide()));
 }
 
@@ -268,11 +269,9 @@ void PackageDetails::setPackage(const QModelIndex &index)
     m_currentIcon       = PkIcons::getIcon(pkgIconPath, QString()).pixmap(64, 64);
     m_appName           = index.data(PackageModel::NameRole).toString();
 
-#ifdef HAVE_APPSTREAM
-    m_currentScreenshot = AppStreamDb::instance()->thumbnail(Transaction::packageName(m_packageID));
+    m_currentScreenshot = thumbnail(Transaction::packageName(m_packageID));
     kDebug() << "current screenshot" << m_currentScreenshot;
-#endif
-    if (!m_currentScreenshot.isEmpty()) {
+    if (!m_currentScreenshot.isNull()) {
         if (m_screenshotPath.contains(m_currentScreenshot)) {
             display();
         } else {
@@ -296,21 +295,13 @@ void PackageDetails::setPackage(const QModelIndex &index)
 
 void PackageDetails::on_screenshotL_clicked()
 {
-    kDebug();
-#ifndef HAVE_APPSTREAM
-    return;
-#else
-    QString screenshot;
-
-    screenshot = AppStreamDb::instance()->screenshot(Transaction::packageName(m_packageID));
-    if (screenshot.isEmpty()) {
-        return;
+    QString url;
+    url = screenshot(Transaction::packageName(m_packageID));
+    if (!url.isNull()) {
+        ScreenShotViewer *view = new ScreenShotViewer(url);
+        view->setWindowTitle(m_appName);
+        view->show();
     }
-
-    ScreenShotViewer *view = new ScreenShotViewer(screenshot);
-    view->setWindowTitle(m_appName);
-    view->show();
-#endif
 }
 
 void PackageDetails::hidePackageVersion(bool hide)
@@ -417,7 +408,7 @@ void PackageDetails::actionActivated(QAction *action)
     }
     kDebug() <<"transaction running";
 
-    PackageKit::Transaction::InternalError error = m_transaction->error();
+    PackageKit::Transaction::InternalError error = m_transaction->internalError();
     if (error) {
         disconnect(m_transaction, SIGNAL(finished(PackageKit::Transaction::Exit,uint)),
                    this, SLOT(finished()));
@@ -716,6 +707,24 @@ QVector<QPair<QString, QString> > PackageDetails::locateApplication(const QStrin
     return ret;
 }
 
+QString PackageDetails::thumbnail(const QString &pkgName) const
+{
+#ifndef HAVE_APPSTREAM
+    return QString();
+#else
+    return AppStream::instance()->thumbnail(pkgName);
+#endif
+}
+
+QString PackageDetails::screenshot(const QString &pkgName) const
+{
+#ifndef HAVE_APPSTREAM
+    return QString();
+#else
+    return AppStream::instance()->screenshot(pkgName);
+#endif
+}
+
 void PackageDetails::description(const QString &packageID,
                                  const QString &license,
                                  PackageKit::Transaction::Group group,
